@@ -18,11 +18,10 @@ log = logging.getLogger(__name__)
 
 
 @contextlib.contextmanager
-def smart_open(filename=None):
-    """See https://stackoverflow.com/questions/17602878/how-to-handle-both-with-open-and-sys-stdout-nicely
-    """
-    if filename and filename != '-':
-        fh = open(filename, 'w')
+def smart_open(filename: str = None):
+    """See https://stackoverflow.com/questions/17602878/how-to-handle-both-with-open-and-sys-stdout-nicely"""  # noqa
+    if filename and filename != "-":
+        fh = open(filename, "w")
     else:
         fh = sys.stdout
 
@@ -33,58 +32,74 @@ def smart_open(filename=None):
             fh.close()
 
 
-def get_version():
+def get_version() -> str:
     dist = pkg_resources.get_distribution("ofxstatement")
     return dist.version
 
 
-def configure_logging(args):
-    format = '%(levelname)s: %(message)s'
+def configure_logging(args: argparse.Namespace) -> None:
+    format = "%(levelname)s: %(message)s"
     arg_level = logging.DEBUG if args.debug else logging.INFO
     logging.basicConfig(format=format, level=arg_level)
 
 
-def make_args_parser():
+def make_args_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(
-        description='Tool to convert proprietary bank statement ' +
-        'to OFX format.')
-    parser.add_argument("--version", action="version",
-                        version='%%(prog)s %s' % get_version(),
-                        help="show current version")
-    parser.add_argument("-d", "--debug", action="store_true",
-                        default=False,
-                        help="show debugging information")
+        description="Tool to convert proprietary bank statement " + "to OFX format."
+    )
+    parser.add_argument(
+        "--version",
+        action="version",
+        version="%%(prog)s %s" % get_version(),
+        help="show current version",
+    )
+    parser.add_argument(
+        "-d",
+        "--debug",
+        action="store_true",
+        default=False,
+        help="show debugging information",
+    )
 
     subparsers = parser.add_subparsers(title="action")
 
     # convert
-    parser_convert = subparsers.add_parser("convert",
-                                           help="convert to OFX")
+    parser_convert = subparsers.add_parser("convert", help="convert to OFX")
 
-    parser_convert.add_argument("-t", "--type",
-                                required=True,
-                                help=("input file type. This is a section in "
-                                      "the config file or plugin name if you "
-                                      "have no config file."))
+    parser_convert.add_argument(
+        "-t",
+        "--type",
+        required=True,
+        help=(
+            "input file type. This is a section in "
+            "the config file or plugin name if you "
+            "have no config file."
+        ),
+    )
     parser_convert.add_argument("input", help="input file to process")
-    parser_convert.add_argument("output", help="output (OFX) file to produce where a minus (-) means writing to standard output instead")
+    parser_convert.add_argument(
+        "output",
+        help=(
+            "output (OFX) file to produce where a minus (-) "
+            "means writing to standard output instead"
+        ),
+    )
     parser_convert.set_defaults(func=convert)
 
     # list-plugins
-    parser_list = subparsers.add_parser("list-plugins",
-                                        help="list available plugins")
+    parser_list = subparsers.add_parser("list-plugins", help="list available plugins")
     parser_list.set_defaults(func=list_plugins)
 
     # edit-config
-    parser_edit = subparsers.add_parser("edit-config",
-                                        help=("open configuration file in "
-                                              "default editor"))
+    parser_edit = subparsers.add_parser(
+        "edit-config", help=("open configuration file in " "default editor")
+    )
     parser_edit.set_defaults(func=edit_config)
 
     return parser
 
 
-def list_plugins(args):
+def list_plugins(args: argparse.Namespace) -> None:
     available_plugins = plugin.list_plugins()
     if not available_plugins:
         print("No plugins available. Install plugin eggs or create your own.")
@@ -101,19 +116,19 @@ def list_plugins(args):
             print("  %-16s %s" % (name, title))
 
 
-def edit_config(args):
-    editors = { 'Linux': 'vim', 'Darwin': 'vi', 'Windows': 'notepad' }
-    editor = os.environ.get('EDITOR', editors[platform.system()])
+def edit_config(args: argparse.Namespace) -> None:
+    editors = {"Linux": "vim", "Darwin": "vi", "Windows": "notepad"}
+    editor = os.environ.get("EDITOR", editors[platform.system()])
     configfname = configuration.get_default_location()
     configdir = os.path.dirname(configfname)
     if not os.path.exists(configdir):
         log.info("Creating confugration directory: %s" % configdir)
         os.makedirs(configdir, mode=0o700)
     log.info("Running editor: %s %s" % (editor, configfname))
-    subprocess.call(shlex.split(editor, posix=(os.name=='posix')) + [configfname])
+    subprocess.call(shlex.split(editor, posix=(os.name == "posix")) + [configfname])
 
 
-def convert(args):
+def convert(args: argparse.Namespace) -> int:
     appui = ui.UI()
     config = configuration.read()
 
@@ -125,13 +140,15 @@ def convert(args):
         # Configuration is loaded
         if args.type not in config:
             log.error("No section '%s' in config file." % args.type)
-            log.error("Edit configuration using ofxstatement edit-config and "
-                      "add section [%s]." % args.type)
+            log.error(
+                "Edit configuration using ofxstatement edit-config and "
+                "add section [%s]." % args.type
+            )
             return 1  # error
 
         settings = dict(config[args.type])
 
-        pname = settings.get('plugin', None)
+        pname = settings.get("plugin", None)
         if not pname:
             log.error("Specify 'plugin' setting for section [%s]" % args.type)
             return 1  # error
@@ -156,7 +173,7 @@ def convert(args):
         statement.assert_valid()
     except exceptions.ValidationError as e:
         log.error("Statement validation error: %s" % (e.message))
-        return 2 # Validation error
+        return 2  # Validation error
 
     with smart_open(args.output) as out:
         writer = ofx.OfxWriter(statement)
@@ -166,9 +183,9 @@ def convert(args):
     return 0  # success
 
 
-def run(args=None):
+def run(argv=None) -> int:
     parser = make_args_parser()
-    args = parser.parse_args(args)
+    args = parser.parse_args(argv)
     configure_logging(args)
 
     if not hasattr(args, "func"):
